==> open-cluster-management-operator-model-6.8.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/OverridesFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class OverridesFluent<A extends OverridesFluent<A>> extends BaseFluent<A>{
  public OverridesFluent() {
  }
  public OverridesFluent(Overrides instance) {
    instance = (instance != null ? instance : new Overrides());

    if (instance != null) {
      this.withImagePullPolicy(instance.getImagePullPolicy());
      this.withImagePullPolicy(instance.getImagePullPolicy());
    }
  }
  private String imagePullPolicy;
  public String getImagePullPolicy() {
    return this.imagePullPolicy;
  }
  public A withImagePullPolicy(String imagePullPolicy) {
    this.imagePullPolicy=imagePullPolicy; return (A) this;
  }
  public boolean hasImagePullPolicy() {
    return this.imagePullPolicy != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OverridesFluent that = (OverridesFluent) o;
    if (!java.util.Objects.equals(imagePullPolicy, that.imagePullPolicy)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(imagePullPolicy,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (imagePullPolicy != null) { sb.append("imagePullPolicy:"); sb.append(imagePullPolicy); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-operator-model-6.9.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/OverridesFluent.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class OverridesFluent<A extends OverridesFluent<A>> extends BaseFluent<A>{
  public OverridesFluent() {
  }
  
  public OverridesFluent(Overrides instance) {
    this.copyInstance(instance);
  }
  private String imagePullPolicy;
  
  protected void copyInstance(Overrides instance) {
    instance = (instance != null ? instance : new Overrides());
    if (instance != null) {
          this.withImagePullPolicy(instance.getImagePullPolicy());
          this.withImagePullPolicy(instance.getImagePullPolicy());
        }
  }
  
  public String getImagePullPolicy() {
    return this.imagePullPolicy;
  }
  
  public A withImagePullPolicy(String imagePullPolicy) {
    this.imagePullPolicy = imagePullPolicy;
    return (A) this;
  }
  
  public boolean hasImagePullPolicy() {
    return this.imagePullPolicy != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OverridesFluent that = (OverridesFluent) o;
    if (!java.util.Objects.equals(imagePullPolicy, that.imagePullPolicy)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(imagePullPolicy,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (imagePullPolicy != null) { sb.append("imagePullPolicy:"); sb.append(imagePullPolicy); }
    sb.append("}");
    return sb.toString();
  }
  

}
